@@ -45,6 +45,7 @@
 import urllib
 #import sqlite3
 import subprocess
+import webbrowser
 try:
     import simplejson as json
 except:
@@ -86,6 +87,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.banner.clicked.connect(self.information)
         self.ui.minimize.clicked.connect(self.minimizefunc)
         self.ui.statsshow.setReadOnly(True)
+        self.ui.about.clicked.connect(self.about)
         #self.ui.playername.home(True)
         #self.ui.playername.returnPressed(self.get_list)
         #if os.path.isfile("defaultplayer.ini"):
@@ -142,7 +144,10 @@ class MainWindow(QtGui.QMainWindow):
             else:
                 pass
                 self.ui.statsshow.setText("No userdata available!")  
-                 
+    
+    
+    def about(self):
+        webbrowser.open("http://www.craveo.de")             
                  
     def hideui(self):
         #print"Fullscreen activated"
@@ -152,6 +157,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.activate.hide()
         self.ui.hidebutton.hide()  
         self.ui.showbutton.show() 
+        self.ui.about.hide()
      
     def releaseui(self):
         #print"Fullscreen deaktivated"
@@ -160,7 +166,8 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.showbutton.hide()
         self.ui.hidebutton.show() 
         self.ui.activate.show()
-        self.ui.search.show()      
+        self.ui.search.show()    
+        self.ui.about.show()  
 
         
     def get_list(self):
